@@ -235,6 +235,9 @@ vcov.emmGrid = function(object, ..., sep = get_emm_option("sep")) {
 #' \item{\code{adjust}}{(\code{character)}) is the default for the \code{adjust}
 #' argument in \code{\link{summary.emmGrid}}.}
 #' 
+#' \item{\code{cross.adjust}}{(\code{character)}) is the default for the \code{cross.adjust}
+#' argument in \code{\link{summary.emmGrid}} (used for adjusting between groups).}
+#' 
 #' \item{\code{famSize}}{(integer) is the number of means involved in a family of
 #' inferences; used in Tukey adjustment}
 #' 
@@ -467,7 +470,8 @@ update.emmGrid = function(object, ..., silent = FALSE) {
 }
 
 ### List of valid strings to match in update() ###
-.valid.misc = c("adjust","alpha","avgd.over","bias.adjust","by.vars","calc","delta","df",
+.valid.misc = c("adjust","alpha","avgd.over","bias.adjust","by.vars","calc",
+                "cross.adjust", "delta","df",
                "initMesg","estName","estType","famSize","frequentist","infer","inv.lbl",
                "level","methDesc","nesting","null","predict.type","pri.vars",
                "side","sigma","tran","tran.mult","tran.offset","tran2","type","is.new.rg",
@@ -501,6 +505,10 @@ update.emmGrid = function(object, ..., silent = FALSE) {
 #'   \code{\link{summary.emmGrid}}, \code{\link{predict.emmGrid}}, \code{\link{test.emmGrid}},
 #'   \code{\link{confint.emmGrid}}, and \code{\link{emmip}}. The only option that can
 #'   affect the latter four is \code{"predict.method"}.}
+#' \item{\code{allow.na.levs}}{A logical value that if \code{TRUE} (the default), allows
+#'   \code{NA} to be among the levels of a factor. Older versions of \pkg{emmeans} did not
+#'   allow this. So if problems come up (say in a messy dataset that includes incomplete cases), 
+#'   try setting this to \code{FALSE}.}
 #' \item{\code{sep}}{A character value to use as a separator in labeling factor combinations.
 #'   Such labels are potentially used in several places such as \code{\link{contrast}} and 
 #'   \code{\link{plot.emmGrid}} when combinations of factors are compared or plotted.
@@ -676,6 +684,7 @@ emm_defaults = list (
     emmeans = list(infer = c(TRUE, FALSE)),
     contrast = list(infer = c(FALSE, TRUE)),
     save.ref_grid = FALSE,    # save new ref_grid in .Last.ref_grid
+    allow.na.levs = TRUE,     # Do we allow factors to have NA as a level?
     cov.keep = "2",           # default for cov.keep arg in ref_grid
     sep = " ",                # separator for combining factor levels
     parens = c("-|\\+|\\/|\\*", "(", ")"), # patterns for what/how to parenthesize in contrast
@@ -1008,6 +1017,7 @@ regrid = function(object, transform = c("response", "mu", "unlink", "none", "pas
         object@V = vcov(object)[estble, estble, drop = FALSE]
         object@bhat = est[[1]]
         object@linfct = diag(1, length(estble))
+        object@misc$regrid.flag = TRUE
         pargs = object@grid[names(object@levels)]
         lbls = do.call(paste, c(pargs, sep = "."))
         if (!is.null(disp <- object@misc$display)) {  # fix up for the bookkeeping in nested models
@@ -1083,6 +1093,7 @@ regrid = function(object, transform = c("response", "mu", "unlink", "none", "pas
                 L[i, ] = apply(X[idx[i,], , drop = FALSE], 2, wmn)
             object@V = L %*% tcrossprod(object@V, L)
             object@linfct = diag(1, nrow(L))
+            object@misc$regrid.flag = TRUE
             if(!is.na(PB[1])) {
                 pb = matrix(0, ncol = nrow(L), nrow = nrow(PB))
                 for (i in seq_len(nrow(idx)))
